var _this = this;
import dayjs from 'dayjs';
const calendarFormat = 'YYYY/MM/DD HH:mm';
const dateFormat = 'YYYY/MM/DD';
export default class utils {
  static getMonths = () => dayjs.months();
  static getMonthName = month => dayjs.months()[month];
  static getWeekdays = () => dayjs.weekdays();
  static getWeekdaysShort = () => dayjs.weekdaysShort();
  static getWeekdaysMin = () => dayjs.weekdaysMin();
  static getFormated = date => dayjs(date).format(calendarFormat);
  static getNow = () => dayjs().format(calendarFormat);
  static getDateMonth = date => dayjs(date).month();
  static getDateYear = date => dayjs(date).year();
  static getDateHour = date => dayjs(date).hour();
  static getDateMinute = date => dayjs(date).minute();
  static getToday = () => dayjs().format(dateFormat);
  static getFormatedDate = (date, format) => dayjs(date).format(format);
  static getDate = date => dayjs(date, calendarFormat);

  /**
   * Calculate month days array based on current date
   *
   * @param {DateType} datetime - The current date that selected
   * @param {boolean} displayFullDays
   * @param {DateType} minimumDate
   * @param {DateType} maximumDate
   * @returns {IDayObject[]} days array based on current date
   */
  static getMonthDays = function () {
    let datetime = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : dayjs();
    let displayFullDays = arguments.length > 1 ? arguments[1] : undefined;
    let minimumDate = arguments.length > 2 ? arguments[2] : undefined;
    let maximumDate = arguments.length > 3 ? arguments[3] : undefined;
    const date = _this.getDate(datetime);
    const currentMonthDays = date.daysInMonth();
    const prevMonthDays = date.add(-1, 'month').daysInMonth();
    const firstDay = date.date(1);
    const dayOfMonth = firstDay.day() % 7;
    const prevDaysArray = Array.from({
      length: dayOfMonth
    }, (_, i) => i + (prevMonthDays - dayOfMonth + 1));
    const monthDaysOffset = dayOfMonth + currentMonthDays;
    const nextMonthDays = displayFullDays ? monthDaysOffset > 35 ? 42 - monthDaysOffset : 35 - monthDaysOffset : 0;
    const prevDays = displayFullDays && prevDaysArray && prevDaysArray.length > 0 ? prevDaysArray === null || prevDaysArray === void 0 ? void 0 : prevDaysArray.map(day => {
      const thisDay = date.add(-1, 'month').date(day);
      let disabled = false;
      if (minimumDate) {
        disabled = thisDay < _this.getDate(minimumDate);
      }
      if (maximumDate && !disabled) {
        disabled = thisDay > _this.getDate(maximumDate);
      }
      return {
        text: day.toString(),
        day,
        date: _this.getFormatedDate(thisDay, 'YYYY/MM/DD'),
        disabled,
        isCurrentMonth: false
      };
    }) : new Array(dayOfMonth);
    const currentDays = Array.from({
      length: currentMonthDays
    }, (_, i) => {
      const thisDay = date.date(i + 1);
      let disabled = false;
      if (minimumDate) {
        disabled = thisDay < _this.getDate(minimumDate);
      }
      if (maximumDate && !disabled) {
        disabled = thisDay > _this.getDate(maximumDate);
      }
      return {
        text: (i + 1).toString(),
        day: i + 1,
        date: _this.getFormatedDate(thisDay, 'YYYY/MM/DD'),
        disabled,
        isCurrentMonth: true
      };
    });
    const nextDays = Array.from({
      length: nextMonthDays
    }, (_, i) => {
      const thisDay = date.add(1, 'month').date(i + 1);
      let disabled = false;
      if (minimumDate) {
        disabled = thisDay < _this.getDate(minimumDate);
      }
      if (maximumDate && !disabled) {
        disabled = thisDay > _this.getDate(maximumDate);
      }
      return {
        text: (i + 1).toString(),
        day: i + 1,
        date: _this.getFormatedDate(thisDay, 'YYYY/MM/DD'),
        disabled,
        isCurrentMonth: false
      };
    });
    return [...prevDays, ...currentDays, ...nextDays];
  };
}
//# sourceMappingURL=utils.js.map